pyDataverse officially supports Python 3.6–3.8

Python packages required:

- `requests <https://requests.readthedocs.io/en/master/>`_>=2.12.0
- `jsonschema <https://github.com/Julian/jsonschema>`_>=3.2.0

External packages required:

- curl (only for :meth:`replace_datafile() <pyDataverse.api.NativeApi.replace_datafile>` necessary)
